.. include:: ../references.txt

CCD Image Processing
====================

.. TODO: Write ccd processing documentation

CCD Processing API
------------------

.. automodapi:: astropop.image.processing
    :no-inheritance-diagram:
